@@ -13,8 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from typing import IO
-
 import addonfactory_splunk_conf_parser_lib as conf_parser
 
 DEFAULT = """
@@ -25,12 +23,16 @@ owner = admin
 access = read : [ * ], write : [ admin, sc_admin ]
 export = system
 """
+DEFAULT_META_FILE_NAME = "default.meta"
 
 
 class MetaConf:
     def __init__(self):
         self._meta_conf = conf_parser.TABConfigParser()
 
-    def create_default(self, fd: IO) -> None:
+    def create_default(self) -> None:
         self._meta_conf.read_string(DEFAULT)
-        self._meta_conf.write(fd)
+
+    def write(self, path: str) -> None:
+        with open(path, "w") as fd:
+            self._meta_conf.write(fd)
